@@ -1,7 +1,5 @@
 #include "biji-marshalers.h"
-
-#include	<glib-object.h>
-
+#include <glib-object.h>
 
 #ifdef G_ENABLE_DEBUG
 #define g_marshal_value_peek_boolean(v)  g_value_get_boolean (v)
@@ -49,7 +47,6 @@
 #define g_marshal_value_peek_variant(v)  (v)->data[0].v_pointer
 #endif /* !G_ENABLE_DEBUG */
 
-
 /* VOID:ENUM,ENUM,POINTER (./biji-marshalers.list:1) */
 void
 _biji_marshal_VOID__ENUM_ENUM_POINTER (GClosure     *closure,
@@ -59,14 +56,14 @@ _biji_marshal_VOID__ENUM_ENUM_POINTER (GClosure     *closure,
                                        gpointer      invocation_hint G_GNUC_UNUSED,
                                        gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__ENUM_ENUM_POINTER) (gpointer     data1,
-                                                        gint         arg_1,
-                                                        gint         arg_2,
-                                                        gpointer     arg_3,
-                                                        gpointer     data2);
-  GMarshalFunc_VOID__ENUM_ENUM_POINTER callback;
-  GCClosure *cc = (GCClosure*) closure;
+  typedef void (*GMarshalFunc_VOID__ENUM_ENUM_POINTER) (gpointer data1,
+                                                        gint arg1,
+                                                        gint arg2,
+                                                        gpointer arg3,
+                                                        gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
   gpointer data1, data2;
+  GMarshalFunc_VOID__ENUM_ENUM_POINTER callback;
 
   g_return_if_fail (n_param_values == 4);
 
@@ -98,13 +95,13 @@ _biji_marshal_VOID__BOOLEAN_BOOLEAN (GClosure     *closure,
                                      gpointer      invocation_hint G_GNUC_UNUSED,
                                      gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__BOOLEAN_BOOLEAN) (gpointer     data1,
-                                                      gboolean     arg_1,
-                                                      gboolean     arg_2,
-                                                      gpointer     data2);
-  GMarshalFunc_VOID__BOOLEAN_BOOLEAN callback;
-  GCClosure *cc = (GCClosure*) closure;
+  typedef void (*GMarshalFunc_VOID__BOOLEAN_BOOLEAN) (gpointer data1,
+                                                      gboolean arg1,
+                                                      gboolean arg2,
+                                                      gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
   gpointer data1, data2;
+  GMarshalFunc_VOID__BOOLEAN_BOOLEAN callback;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -135,13 +132,13 @@ _biji_marshal_VOID__POINTER_ENUM (GClosure     *closure,
                                   gpointer      invocation_hint G_GNUC_UNUSED,
                                   gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__POINTER_ENUM) (gpointer     data1,
-                                                   gpointer     arg_1,
-                                                   gint         arg_2,
-                                                   gpointer     data2);
-  GMarshalFunc_VOID__POINTER_ENUM callback;
-  GCClosure *cc = (GCClosure*) closure;
+  typedef void (*GMarshalFunc_VOID__POINTER_ENUM) (gpointer data1,
+                                                   gpointer arg1,
+                                                   gint arg2,
+                                                   gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
   gpointer data1, data2;
+  GMarshalFunc_VOID__POINTER_ENUM callback;
 
   g_return_if_fail (n_param_values == 3);
 
